@@ -48,8 +48,8 @@ class Cli():
 
         if '--help' in argv:
             table = [[f'--{o.long_name}', o.description] for o in Cli.options]
-            text = f'Usage: flatpak run {APP_ID} [OPTION...]'
-            text += f'\nFor a better user experience, please set `alias gearlever=\'flatpak run {APP_ID}\'` in your .bashrc file'
+            text = f'Usage: gearlever [OPTION...]'
+            text += f'\nFor a better user experience, please set `alias gearlever=\'gearlever\'` in your .bashrc file'
             Cli._print_help_if_requested(argv, table, text)
 
         return -1
