@@ -489,10 +489,12 @@ class GitlabUpdater(UpdateManager):
             if paths[1] != 'api' or paths[2] != 'v4' or paths[5] != 'packages':
                 return False
 
-        return {
-            'username': paths[4],
-            'filename': paths[9],
-        }
+            return {
+                'username': paths[4],
+                'filename': paths[9],
+            }
+
+        return False
 
     def can_handle_link(url: str):
         return GitlabUpdater.get_url_data(url) != False
@@ -638,11 +640,13 @@ class CodebergUpdater(UpdateManager):
             if len(paths) != 7:
                 return False
 
-        return {
-            'username': paths[1],
-            'repo': paths[2],
-            'filename': paths[6],
-        }
+            return {
+                'username': paths[1],
+                'repo': paths[2],
+                'filename': paths[6],
+            }
+
+        return False
 
     def can_handle_link(url: str):
         return CodebergUpdater.get_url_data(url) != False
